@@ -4,7 +4,7 @@ package Tree::Simple;
 use strict;
 use warnings;
 
-our $VERSION = '0.14';
+our $VERSION = '0.15';
 
 ## ----------------------------------------------------------------------------
 ## Tree::Simple
@@ -51,7 +51,7 @@ sub _init {
 sub _setParent {
 	my ($self, $parent) = @_;
 	(defined($parent) && 
-		(($parent eq ROOT) || (ref($parent) && $parent->isa("Tree::Simple"))))
+		(($parent eq ROOT) || (ref($parent) && UNIVERSAL::isa($parent, "Tree::Simple"))))
 		|| die "Insufficient Arguments : parent also must be a Tree::Simple object";
 	$self->{_parent} = $parent;
 	if ($parent eq ROOT) {
@@ -76,7 +76,7 @@ sub setNodeValue {
 
 sub addChild {
 	my ($self, $tree) = @_;
-	(defined($tree) && ref($tree) && $tree->isa("Tree::Simple")) 
+	(defined($tree) && ref($tree) && UNIVERSAL::isa($tree, "Tree::Simple")) 
 		|| die "Insufficient Arguments : Child must be a Tree::Simple object";
 	$tree->_setParent($self);
 	$tree->fixDepth() unless $tree->isLeaf();
@@ -101,7 +101,7 @@ sub insertChildren {
 	(@trees) 
 		|| die "Insufficient Arguments : no tree(s) to insert";	
 	foreach my $tree (@trees) {
-		(defined($tree) && ref($tree) && $tree->isa("Tree::Simple")) 
+		(defined($tree) && ref($tree) && UNIVERSAL::isa($tree, "Tree::Simple")) 
 			|| die "Insufficient Arguments : Child must be a Tree::Simple object";	
 		$tree->_setParent($self);
 		$tree->fixDepth() unless $tree->isLeaf();
@@ -325,7 +325,7 @@ sub traverse {
 # its disposal. 
 sub accept {
 	my ($self, $visitor) = @_;
-	(defined($visitor) && ref($visitor) && $visitor->isa("Tree::Simple::Visitor")) 
+	(defined($visitor) && ref($visitor) && UNIVERSAL::isa($visitor, "Tree::Simple::Visitor")) 
 		|| die "Insufficient Arguments : You must supply a valid Tree::Simple::Visitor object";
 	$visitor->visit($self);
 }
@@ -499,7 +499,7 @@ This module uses exceptions and a minimal Design By Contract style. All method a
 
 =over 4
 
-=item ROOT
+=item B<ROOT>
 
 This class constant serves as a placeholder for the root of our tree. If a tree does not have a parent, then it is considered a root. 
 
@@ -511,7 +511,7 @@ This class constant serves as a placeholder for the root of our tree. If a tree
 
 =over 4
 
-=item new ($node, $parent)
+=item B<new ($node, $parent)>
 
 The constructor accepts two arguments a C<$node> value and an optional C<$parent>. The C<$node> value can be any scalar value (which includes references and objects). The optional C<$parent> value must be a B<Tree::Simple> object, or an object derived from B<Tree::Simple>. Setting this value implies that your new tree is a child of the parent tree, and therefore adds it to the parent's children. If the C<$parent> is not specified then its value defaults to ROOT.
 
@@ -521,11 +521,11 @@ The constructor accepts two arguments a C<$node> value and an optional C<$parent
 
 =over 4
 
-=item setNodeValue ($node_value)
+=item B<setNodeValue ($node_value)>
 
 This sets the node value to the scalar C<$node_value>, an exception is thrown if C<$node_value> is not defined.
 
-=item addChild ($tree)
+=item B<addChild ($tree)>
 
 This method accepts only B<Tree::Simple> objects or objects derived from B<Tree::Simple>, an exception is thrown otherwise. This method will append the given C<$tree> to the end of it's children list, and set up the correct parent-child relationships. This method is set up to return its invocant so that method call chaining can be possible. Such as:
 
@@ -539,29 +539,29 @@ Or the more complex:
                                      )
                          );
 
-=item addChildren (@trees)
+=item B<addChildren (@trees)>
 
 This method accepts an array of B<Tree::Simple> objects, and adds them to it's children list. Like C<addChild> this method will return its invocant to allow for method call chaining.
 
-=item insertChild ($index, $tree)
+=item B<insertChild ($index, $tree)>
 
 This method accepts a numeric C<$index> and a B<Tree::Simple> object (C<$tree>), and inserts the C<$tree> into the children list at the specified C<$index>. This results in the shifting down of all children after the C<$index>. The C<$index> is checked to be sure it is the bounds of the child list, if it out of bounds an exception is thrown. The C<$tree> argument's type is verified to be a B<Tree::Simple> or B<Tree::Simple> derived object, if this condition fails, an exception is thrown. 
 
-=item insertChildren ($index, @trees)
+=item B<insertChildren ($index, @trees)>
 
 This method functions much as insertChild does, but instead of inserting a single B<Tree::Simple>, it inserts an array of B<Tree::Simple> objects. It too bounds checks the value of C<$index> and type checks the objects in C<@trees> just as C<insertChild> does.
 
-=item removeChild ($index)
+=item B<removeChild ($index)>
 
 This method accepts a numeric C<$index> and removes the tree found at that index from it's children list. This results in the shifting up of all children after the C<$index>. The C<$index> is checked to be sure it is the bounds of the child list, if this condition fail, an exception is thrown. The removed child is then returned.
 
-=item addSibling ($tree)
+=item B<addSibling ($tree)>
 
-=item addSiblings (@trees)
+=item B<addSiblings (@trees)>
 
-=item insertSibling ($index, $tree)
+=item B<insertSibling ($index, $tree)>
 
-=item insertSiblings ($index, @trees)
+=item B<insertSiblings ($index, @trees)>
 
 The C<addSibling>, C<addSiblings>, C<insertSibling> and C<insertSiblings> methods pass along their arguments to the C<addChild>, C<addChildren>, C<insertChild> and C<insertChildren> methods of their parent object respectively. This eliminates the need to overload these methods in subclasses which may have specialized versions of the *Child(ren) methods. The one exceptions is that if an attempt it made to add or insert siblings to the B<ROOT> of the tree then an exception is thrown.
 
@@ -574,33 +574,33 @@ There is no C<removeSibling> method as I felt it was probably a bad idea. The sa
 
 =over 4
 
-=item getNodeValue
+=item B<getNodeValue>
 
 This returns the value stored in the object's node field.
 
-=item getChild ($index)
+=item B<getChild ($index)>
 
 This returns the child (a B<Tree::Simple> object) found at the specified C<$index>. Note that we do use standard zero-based array indexing.
 
-=item getAllChildren
+=item B<getAllChildren>
 
 This returns an array of all the children (all B<Tree::Simple> objects). It will return an array reference in scalar context. 
 
-=item getSibling ($index)
+=item B<getSibling ($index)>
 
-=item getAllSiblings
+=item B<getAllSiblings>
 
 Much like C<addSibling> and C<addSiblings>, these two methods simply call C<getChild> and C<getAllChildren> on the invocant's parent.
 
-=item getDepth
+=item B<getDepth>
 
 Returns a number representing the invocant's depth within the hierarchy of B<Tree::Simple> objects.
 
-=item getParent
+=item B<getParent>
 
 Returns the invocant's parent, which could be either B<ROOT> or a B<Tree::Simple> object.
 
-=item getChildCount
+=item B<getChildCount>
 
 Returns the number of children the invocant contains.
 
@@ -610,11 +610,11 @@ Returns the number of children the invocant contains.
 
 =over 4
 
-=item isLeaf
+=item B<isLeaf>
 
 Returns true (1) if the invocant does not have any children, false (0) otherwise.
 
-=item isRoot
+=item B<isRoot>
 
 Returns true (1) if the invocant's parent is B<ROOT>, returns false (0) otherwise.
 
@@ -624,7 +624,7 @@ Returns true (1) if the invocant's parent is B<ROOT>, returns false (0) otherwis
 
 =over 4
 
-=item traverse (CODE)
+=item B<traverse ($func)>
 
 This method takes a single argument of a subroutine reference C<$func>. If the argument is not defined and is not in fact a CODE reference then an exception is thrown. The function is then applied recursively to all the children of the invocant. Here is an example of a traversal function that will print out the hierarchy as a tabbed in list.
 
@@ -633,21 +633,21 @@ This method takes a single argument of a subroutine reference C<$func>. If the a
         print (("\t" x $_tree->getDepth()), $_tree->getNodeValue(), "\n");
         });
 
-=item accept ($visitor)
+=item B<accept ($visitor)>
 
 It accepts a B<Tree::Simple::Visitor> object (or somethings derived from a B<Tree::Simple::Visitor>) and runs the Visitor's C<visit> method. We verify with an assertion that it is in fact a valid B<Tree::Simple::Visitor> object and that it does have a method B<visit> at its disposal. 
 
-=item clone 
+=item B<clone>
 
-The clone method does a full deep-copy clone of the object, calling clone recursively on all its children. This does not call clone on the parent object however. Doing this would result in a slowly degenerating spiral of recursive death, so it is not recommended and therefore not implemented. What it does do is to copy the parent reference, which is a much more sensible act, and tends to be closer to what we are looking for. This can be a very expensive operation, and should only be undertaken with great care. More often than not, this method will not be appropriate. I recommend using the C<cloneShallow> method instead.
+The clone method does a full deep-copy clone of the object, calling C<clone> recursively on all its children. This does not call C<clone> on the parent tree however. Doing this would result in a slowly degenerating spiral of recursive death, so it is not recommended and therefore not implemented. What it does do is to copy the parent reference, which is a much more sensible act, and tends to be closer to what we are looking for. This can be a very expensive operation, and should only be undertaken with great care. More often than not, this method will not be appropriate. I recommend using the C<cloneShallow> method instead.
 
-=item cloneShallow
+=item B<cloneShallow>
 
 This method is an alternate option to the plain C<clone> method. This method allows the cloning of single B<Tree::Simple> object while retaining connections to the rest of the tree/hierarchy. This will attempt to call C<clone> on the invocant's node if the node is an object (and responds to C<$obj-E<gt>can('clone')>) otherwise it will just copy it.
 
-=item DESTROY
+=item B<DESTROY>
 
-To avoid memory leaks through uncleaned-up circular references, we implement the DESTROY method. This method will attempt to call DESTROY on each of its children (if it as any). This will result in a cascade of calls to DESTROY on down the tree. This may not be a good idea, we will have to see how it works out in practice.
+To avoid memory leaks through uncleaned-up circular references, we implement the C<DESTROY> method. This method will attempt to call C<DESTROY> on each of its children (if it as any). This will result in a cascade of calls to C<DESTROY> on down the tree. 
 
 =back
 
@@ -655,11 +655,11 @@ To avoid memory leaks through uncleaned-up circular references, we implement the
 
 =over 4
 
-=item _init ($node, $parent, $children)
+=item B<_init ($node, $parent, $children)>
 
 This method is here largely to facilitate subclassing. This method is called by new to initialize the object, where new's primary responsibility is creating the instance.
 
-=item _setParent ($parent)
+=item B<_setParent ($parent)>
 
 This method sets up the parental relationship. It is for internal use only.
 
@@ -667,63 +667,64 @@ This method sets up the parental relationship. It is for internal use only.
 
 =head1 CODE COVERAGE
 
-I use Devel::Cover to test the code coverage of my modules, below is the Devel::Cover report on this modules test suite.
-
-	----------------------------------- ------ ------ ------ ------ ------
-	File                                  stmt branch   cond    sub  total
-	----------------------------------- ------ ------ ------ ------ ------
-	lib//Tree/Simple.pm                  100.0   98.6   75.6  100.0   95.9
-	lib//Tree/Simple/Visitor.pm           82.4   50.0   35.3  100.0   58.3
-	t/10_Tree_Simple_test.t              100.0    n/a    n/a  100.0  100.0
-	t/11_Tree_Simple_fixDepth_test.t     100.0    n/a    n/a    n/a  100.0
-	t/12_Tree_Simple_exceptions_test.t   100.0    n/a    n/a  100.0  100.0
-	t/13_Tree_Simple_clone_test.t        100.0    n/a    n/a  100.0  100.0
-	t/20_Tree_Simple_Visitor_test.t      100.0    n/a    n/a  100.0  100.0
-	----------------------------------- ------ ------ ------ ------ ------
-	Total                                 99.5   91.9   64.5  100.0   96.1
-	----------------------------------- ------ ------ ------ ------ ------
+I use B<Devel::Cover> to test the code coverage of my tests, below is the B<Devel::Cover> report on this module's test suite.
+ 
+ ----------------------------------- ------ ------ ------ ------ ------ ------ ------
+ File                                  stmt branch   cond    sub    pod   time  total
+ ----------------------------------- ------ ------ ------ ------ ------ ------ ------
+ /Tree/Simple.pm                      100.0   98.6   75.6  100.0   95.8   10.9   95.9
+ /Tree/Simple/Visitor.pm              100.0  100.0   90.0  100.0  100.0    3.2   96.2
+ t/10_Tree_Simple_test.t              100.0    n/a    n/a  100.0    n/a   88.8  100.0
+ t/11_Tree_Simple_fixDepth_test.t     100.0    n/a    n/a    n/a    n/a    5.7  100.0
+ t/12_Tree_Simple_exceptions_test.t   100.0    n/a    n/a  100.0    n/a   14.8  100.0
+ t/13_Tree_Simple_clone_test.t        100.0    n/a    n/a  100.0    n/a   60.1  100.0
+ t/20_Tree_Simple_Visitor_test.t      100.0    n/a    n/a  100.0    n/a  100.0  100.0
+ ----------------------------------- ------ ------ ------ ------ ------ ------ ------ 
+ Total                                100.0   98.8   80.0  100.0   96.2  100.0   98.3
+ ----------------------------------- ------ ------ ------ ------ ------ ------ ------
+ 
 
 =head1 OTHER TREE MODULES
 
-There are a few other Tree modules out there, here is a quick comparison between Tree::Simple and them. Obviously I am biased, so take what I say with a grain of salt, and keep in mind, I wrote Tree::Simple because I could not find a Tree module that suited my needs. If Tree::Simple does not fit your needs, I recommend looking at these modules. Please note that I only list registered Tree::* modules here, I have only seen a few other modules outside of that namespace that seem to fit, although most of them are part of another distribution (HTML::Tree, Pod::Tree, etc). 
+There are a few other Tree modules out there, here is a quick comparison between B<Tree::Simple> and them. Obviously I am biased, so take what I say with a grain of salt, and keep in mind, I wrote B<Tree::Simple> because I could not find a Tree module that suited my needs. If B<Tree::Simple> does not fit your needs, I recommend looking at these modules. Please note that I only list registered Tree::* modules here, I have only seen a few other modules outside of that namespace that seem to fit, although most of them are part of another distribution (B<HTML::Tree>, B<Pod::Tree>, etc). 
 
 =over 4
 
-=item Tree::DAG_Node
+=item B<Tree::DAG_Node>
 
-This module seems pretty stable and very robust, but it is also very large module. It is approx. 3000 lines with POD, and 1,500 without the POD. The shear depth and detail of the documentation and the ratio of code to documentation is impressive, and not to be taken lightly. Tree::Simple, by comparison, is a mere 450 lines of code and another 250 lines of documentation, hence the Simple part of the name. Tree::DAG_Node is part of the reason why I wrote Tree::Simple, the author contends that you can use Tree::DAG_Node for simpler purposes if you so desire, for me it is too beefy. 
+This module seems pretty stable and very robust, but it is also very large module. It is approx. 3000 lines with POD, and 1,500 without the POD. The shear depth and detail of the documentation and the ratio of code to documentation is impressive, and not to be taken lightly. B<Tree::Simple>, by comparison, is a mere 450 lines of code and another 250 lines of documentation, hence the Simple in the name. B<Tree::DAG_Node> is part of the reason why I wrote B<Tree::Simple>, the author contends that you can use B<Tree::DAG_Node> for simpler purposes if you so desire, for me it is too beefy. 
 
-My other issue with Tree::DAG_Node is its test-suite. There is one test, and that is that the module loads. This is not acceptable to me, no matter how good a module is. Tree::Simple on the other hand has 372 tests which covers approx. 96% of the code (see the L<CODE COVERAGE> section above).
+My other issue with B<Tree::DAG_Node> is its test-suite. There is one test, and that is that the module loads. This is not acceptable to me, no matter how good a module is. B<Tree::Simple> on the other hand has 391 tests which covers approx. 98% of the code (see the L<CODE COVERAGE> section above).
 
-=item Tree::Nary
+=item B<Tree::Nary>
 
 It is a (somewhat) direct translation of the N-ary tree from the GLIB library, and the API is based on that. GLIB is a C library, which means this is a very C-ish API. That doesn't appeal to me, it might to you, to each their own.
 
-This module is similar in intent to Tree::Simple. It implements a tree with I<n> branches and has polymorphic node containers. It implements much of the same methods as Tree::Simple and a few others on top of that, but being based on a C library, is not very OO. In most of the method calls the C<$self> argument is not used and the second argument C<$node> is. Tree::Simple is a much more OO module than Tree::Nary, so while they are similar in functionality they greatly differ in implementation style.
+This module is similar in intent to B<Tree::Simple>. It implements a tree with I<n> branches and has polymorphic node containers. It implements much of the same methods as B<Tree::Simple> and a few others on top of that, but being based on a C library, is not very OO. In most of the method calls the C<$self> argument is not used and the second argument C<$node> is. B<Tree::Simple> is a much more OO module than B<Tree::Nary>, so while they are similar in functionality they greatly differ in implementation style.
 
-=item Tree
+=item B<Tree>
 
-This module is pretty old, it has not been updated since Oct. 31, 1999 and is still on version 0.01. It also seems to be (from the limited documentation) a balanced tree, Tree::Simple makes no attempt to balance anything.
+This module is pretty old, it has not been updated since Oct. 31, 1999 and is still on version 0.01. It also seems to be (from the limited documentation) a balanced tree, B<Tree::Simple> makes no attempt to balance anything.
 
-=item Tree::Ternary
+=item B<Tree::Ternary>
 
-This module is older than Tree, last update was Sept. 24th, 1999. It seems to be a special purpose tree, for storing and accessing strings, not general purpose like Tree::Simple. 
+This module is older than B<Tree>, last update was Sept. 24th, 1999. It seems to be a special purpose tree, for storing and accessing strings, not general purpose like B<Tree::Simple>. 
 
-=item Tree::Ternary_XS
+=item B<Tree::Ternary_XS>
 
 This module is an XS implementation of the above tree type. 
 
-=item Tree::Trie
+=item B<Tree::Trie>
 
-This too is a specialized tree type, it sounds similar to the Tree::Ternary, but it much newer (latest release in 2003). It seems specialized for the lookup and retrieval of information like a hash.
+This too is a specialized tree type, it sounds similar to the B<Tree::Ternary>, but it much newer (latest release in 2003). It seems specialized for the lookup and retrieval of information like a hash.
 
-=item Tree::M
+=item B<Tree::M>
 
-Is a wrapper for a C++ library, whereas Tree::Simple is pure-perl. It also seems to be a more specialized implementation of a tree, therefore not really the same as Tree::Simple 
+Is a wrapper for a C++ library, whereas B<Tree::Simple> is pure-perl. It also seems to be a more specialized implementation of a tree, therefore not really the same as B<Tree::Simple>. 
 
-=item Tree::Fat
+=item B<Tree::Fat>
 
-Is a wrapper around a C library, again Tree::Simple is pure-perl. The author describes FAT-trees as a combination of a Tree and an array. It looks like a pretty mean and lean module, and good if you need speed and are implementing a custom data-store of some kind. The author points out too that the module is designed for embedding and there is not default embedding, so you can't really use it "out of the box".
+Is a wrapper around a C library, again B<Tree::Simple> is pure-perl. The author describes FAT-trees as a combination of a Tree and an array. It looks like a pretty mean and lean module, and good if you need speed and are implementing a custom data-store of some kind. The author points out too that the module is designed for embedding and there is not default embedding, so you can't really use it "out of the box".
 
 =back
 
